get_header_end_idx: Get the index of the end of the header in the first column
Description
Get the index of the end of the header in the first column
Usage
get_header_end_idx(first_col)
Value
The index of the last row of the header
Arguments
- first_col
The first column of the BIOPLEX excel sheet